@@ -16,7 +16,7 @@ use Module::Runtime   qw(require_module);
 use Try::Tiny;
 
 # Version set by dist.ini; do not change here.
-our $VERSION = '0.07_01'; # VERSION
+our $VERSION = '0.07_02'; # VERSION
 
 {
     my(%cvs_bin_of);
@@ -32,7 +32,8 @@ our $VERSION = '0.07_01'; # VERSION
         return $self;
     }
 
-    sub _init {
+    sub _init 
+    {
         my($self) = shift;
         my(%args) = @_;
 
@@ -84,7 +85,8 @@ our $VERSION = '0.07_01'; # VERSION
         }
     }
 
-    sub callback {
+    sub callback 
+    {
         my($self) = shift;
         my($hook) = shift;
         my($func) = shift;
@@ -110,7 +112,8 @@ our $VERSION = '0.07_01'; # VERSION
         }
     }
 
-    sub unset_callback {
+    sub unset_callback 
+    {
         my($self) = shift;
         my($hook) = shift;
 
@@ -121,283 +124,296 @@ our $VERSION = '0.07_01'; # VERSION
         return delete $callback_of{ident $self}{$hook};
     }
 
-sub cvs_bin {
-    my($self) = shift;
+    sub cvs_bin 
+    {
+        my($self) = shift;
 
-    if(@_==1) {
-        $cvs_bin_of{ident $self} = shift; 
-    }
-
-    return $cvs_bin_of{ident $self};
-}
-
-sub _pipe {
-    my($cmd) = shift;
-
-    my($fh) = IO::Pipe->new;
-    $fh->reader( "$cmd 2>&1" );
-    defined($fh) or croak "Failed to open $cmd:$!";
-    my($SH) = IO::Lines->new();
-    $SH->print( $fh->getlines );
-
-    $fh->close or carp "Close failed:$!";
-
-    return $SH;
-}
-
-sub cvs_cmd {
-    my($self) = shift;
-    my($cmd)  = shift;
-
-    croak "Syntax: cvs_cmd(cmd)" unless (defined($cmd) && $cmd);
-
-    STDOUT->autoflush;
-
-    my($hook)= Cvs::Simple::Hook::get_hook $cmd;
-
-    my($fh) = _pipe( "$cmd 2>&1" );
-
-    my($hookfunc) = $self->callback($hook) ||
-                    $self->callback();
-
-    if(defined( $hookfunc )) {
-        while(defined($_=$fh->getline)) {
-            $hookfunc->( $cmd, $_ );
+        if(@_==1) {
+            $cvs_bin_of{ident $self} = shift; 
         }
-    }
-    else {
-        print STDOUT $fh->getlines;
+
+        return $cvs_bin_of{ident $self};
     }
 
-    $fh->close;
+    sub _pipe 
+    {
+        my($cmd) = shift;
 
-    return 1;
-}
+        my($fh) = IO::Pipe->new;
+        $fh->reader( "$cmd 2>&1" );
+        defined($fh) or croak "Failed to open $cmd:$!";
+        my($SH) = IO::Lines->new();
+        $SH->print( $fh->getlines );
 
-sub merge {
+        $fh->close or carp "Close failed:$!";
+
+        return $SH;
+    }
+
+    sub cvs_cmd 
+    {
+        my($self) = shift;
+        my($cmd)  = shift;
+
+        croak "Syntax: cvs_cmd(cmd)" unless (defined($cmd) && $cmd);
+
+        STDOUT->autoflush;
+
+        my($hook)= Cvs::Simple::Hook::get_hook $cmd;
+
+        my($fh) = _pipe( "$cmd 2>&1" );
+
+        my($hookfunc) = $self->callback($hook) ||
+        $self->callback();
+
+        if(defined( $hookfunc )) {
+            while(defined($_=$fh->getline)) {
+                $hookfunc->( $cmd, $_ );
+            }
+        } else {
+            print STDOUT $fh->getlines;
+        }
+
+        $fh->close;
+
+        return 1;
+    }
+
+    sub merge 
+    {
 # merge(old_rev,new_rev,file);
-    my($self) = shift;
-    my(@args) = @_;
+        my($self) = shift;
+        my(@args) = @_;
 
-    croak "Syntax: merge(old_rev,new_rev,file)"
+        croak "Syntax: merge(old_rev,new_rev,file)"
         unless (@args && scalar(@args)==3);
 
-    my($cmd) = $self->_cmd('-q update');
-    $cmd .= sprintf("-j%s -j%s %s", @args);
+        my($cmd) = $self->_cmd('-q update');
+        $cmd .= sprintf("-j%s -j%s %s", @args);
 
-    return $self->cvs_cmd($cmd);
-}
+        return $self->cvs_cmd($cmd);
+    }
 
-sub undo {
-    goto &backout;
-}
+    sub undo 
+    {
+        goto &backout;
+    }
 
-sub backout {
+    sub backout 
+    {
 # Revert to previous revision of a file, i.e. backout/undo change(s).
 # backout(current_rev,revert_rev,file);
-    my($self) = shift;
-    my(@args) = @_;
+        my($self) = shift;
+        my(@args) = @_;
 
-    unless (@args && scalar(@args)==3) {
-        croak <<SYN;
+        unless (@args && scalar(@args)==3) {
+            croak <<SYN;
 Syntax: backout(current_rev,revert_rev,file)
         undo   (current_rev,revert_rev,file)
 SYN
+        }
+
+        return $self->merge(@args);
     }
 
-    return $self->merge(@args);
-}
+    sub external 
+    {
+        my($self)  = shift;
 
-sub external {
-    my($self)  = shift;
-
-    if(@_==1) {
-        $repos_of{ident $self} = shift;
+        if(@_==1) {
+            $repos_of{ident $self} = shift;
+        }
+        return $repos_of{ident $self};
     }
-    return $repos_of{ident $self};
-}
 
-sub _cmd {
-    my($self) = shift;
-    my($type) = shift;
+    sub _cmd 
+    {
+        my($self) = shift;
+        my($type) = shift;
 
-    my($cvs)  = $self->cvs_bin;
+        my($cvs)  = $self->cvs_bin;
 
-    my($cmd) = 
+        my($cmd) = 
         $self->external  ?   sprintf("%s -d %s %s ", $cvs,$self->external,$type)
-                         :   sprintf("%s %s ",       $cvs,$type);
+        :   sprintf("%s %s ",       $cvs,$type);
 
-    return $cmd;
-}
+        return $cmd;
+    }
 
-sub add {
+    sub add 
+    {
 #   Can only be called as:
 #    cvs add file1 [, .... , ]
-    my($self) = shift;
-    my(@args) = @_;
+        my($self) = shift;
+        my(@args) = @_;
 
-    croak "Syntax: add(file1, ...)" unless(@args);
+        croak "Syntax: add(file1, ...)" unless(@args);
 
-    my($cmd) = $self->_cmd('add');
+        my($cmd) = $self->_cmd('add');
 
-    if(@args) {
-        $cmd .= join ' ' => @args;
+        if(@args) {
+            $cmd .= join ' ' => @args;
+        }
+
+        return $self->cvs_cmd($cmd);
     }
 
-    return $self->cvs_cmd($cmd);
-}
-
-sub add_bin {
+    sub add_bin 
+    {
 # Can only be called as :
 #    cvs add -kb file1 [, .... , ]
-    my($self) = shift;
-    my(@args) = @_;
+        my($self) = shift;
+        my(@args) = @_;
 
-    croak "Syntax: add_bin(file1, ...)" unless (@args);
+        croak "Syntax: add_bin(file1, ...)" unless (@args);
 
-    my($cmd) = $self->_cmd('add -kb');
+        my($cmd) = $self->_cmd('add -kb');
 
-    if(@args) {
-        $cmd .= join ' ' => @args;
+        if(@args) {
+            $cmd .= join ' ' => @args;
+        }
+
+        return $self->cvs_cmd($cmd);
     }
 
-    return $self->cvs_cmd($cmd);
-}
-
-sub checkout {
+    sub checkout 
+    {
 # Can be called as:
 #  cvs co module
 #  cvs co -r tag module
 #  Calling signature is checkout(tag,module) or checkout(module).
-    my($self) = shift;
-    my(@args) = @_;
+        my($self) = shift;
+        my(@args) = @_;
 
-    unless (@args && (scalar(@args)==2 || scalar(@args)==1)) {
-    croak <<SYN;
+        unless (@args && (scalar(@args)==2 || scalar(@args)==1)) {
+            croak <<SYN;
 Syntax: co(tag)
         co(module)
         checkout(tag)
         checkout(module)
 SYN
 
+        }
+
+        my($cmd) = $self->_cmd('co');
+
+        $cmd    .= @args==2         ?   sprintf("-r %s %s", @args)
+        :   sprintf("%s", @args);
+
+        return $self->cvs_cmd($cmd);
     }
 
-    my($cmd) = $self->_cmd('co');
+    sub co {
+        goto &checkout;
+    }
 
-    $cmd    .= @args==2         ?   sprintf("-r %s %s", @args)
-                                :   sprintf("%s", @args);
+    sub _pattern {
+        return join '' => ('%s ' x @{$_[0]});
+    }
 
-    return $self->cvs_cmd($cmd);
-}
-
-sub co {
-    goto &checkout;
-}
-
-sub _pattern {
-    return join '' => ('%s ' x @{$_[0]});
-}
-
-sub commit {
+    sub commit {
 # Can be called as :
 # commit()
 # commit([file_list])
 # commit(tag1)
 # commit(tag1, [file_list])
-    my($self) = shift;
-    my(@args) = @_;
+        my($self) = shift;
+        my(@args) = @_;
 
-    my($cmd) = $self->_cmd('commit -m ""');
-    if(scalar(@args)==0) { # 'cvs commit -m ""'
-        return $self->cvs_cmd($cmd);
-    }
-    elsif(@args==2) { # 'cvs commit -m "" -r TAG file(s)'
-        croak "Syntax: commit([rev],[\@filelist])"
+        my($cmd) = $self->_cmd('commit -m ""');
+        if(scalar(@args)==0) { # 'cvs commit -m ""'
+            return $self->cvs_cmd($cmd);
+        } elsif(@args==2) { # 'cvs commit -m "" -r TAG file(s)'
+            croak "Syntax: commit([rev],[\@filelist])"
             unless (UNIVERSAL::isa($args[1], 'ARRAY'));
-        my($pattern) = join '' => '-r %s ', _pattern($args[1]);
-        $cmd .= sprintf($pattern, $args[0], @{$args[1]});
-        return $self->cvs_cmd($cmd);
-    }
-    elsif(@args==1) { # 'cvs commit -m "" -r TAG' or 
-                      # 'cvs commit -m "" file(s)'
-        my($pattern);
-        if(UNIVERSAL::isa($args[0], 'ARRAY')) {
-            $pattern = sprintf(_pattern($args[0]), @{$args[0]});
-        }
-        else {
-            $pattern = sprintf('-r %s', $args[0]);
-        }
+            my($pattern) = join '' => '-r %s ', _pattern($args[1]);
+            $cmd .= sprintf($pattern, $args[0], @{$args[1]});
+            return $self->cvs_cmd($cmd);
+        } elsif(@args==1) { # 'cvs commit -m "" -r TAG' or 
+            # 'cvs commit -m "" file(s)'
+            my($pattern);
+            if(UNIVERSAL::isa($args[0], 'ARRAY')) {
+                $pattern = sprintf(_pattern($args[0]), @{$args[0]});
+            }
+            else {
+                $pattern = sprintf('-r %s', $args[0]);
+            }
 
-        $cmd .= $pattern;
+            $cmd .= $pattern;
 
-        return $self->cvs_cmd($cmd);
-    }
-    else { # Anything else is an error
-        croak <<SYN
+            return $self->cvs_cmd($cmd);
+        } else { # Anything else is an error
+            croak <<SYN
 Syntax: commit([rev],[\@filelist])
         ci    ([rev],[\@filelist])
 SYN
 
+        }
     }
-}
 
-sub ci {
-    goto &commit;
-}
+    sub ci 
+    {
+        goto &commit;
+    }
 
-sub diff {
+    sub diff 
+    {
 # Can be called as :
 # diff(file_or_dir)
 # diff(tag1,tag2,file_or_dir)
-    my($self) = shift;
-    my(@args) = @_;
+        my($self) = shift;
+        my(@args) = @_;
 
-    croak "Syntax: diff(file) or diff(tag1,tag2,file)"
+        croak "Syntax: diff(file) or diff(tag1,tag2,file)"
         unless (@args && (scalar(@args)==1 || scalar(@args)==3));
 
-    my($cmd) = $self->_cmd('diff -c');
+        my($cmd) = $self->_cmd('diff -c');
 
-    $cmd .=     @args==3    ?   sprintf("-r %s -r %s %s", @args)
-                            :   sprintf("%s"            , @args);
+        $cmd .=     @args==3    ?   sprintf("-r %s -r %s %s", @args)
+        :   sprintf("%s"            , @args);
 
-    return $self->cvs_cmd($cmd);
-}
-
-sub status {
-# status()
-# status(file1, ... )
-    my($self) = shift;
-    my(@args) = @_;
-
-    my($cmd) = $self->_cmd('status -v');
-
-    if(@args) {
-        $cmd .= join ' ' => @args;
+        return $self->cvs_cmd($cmd);
     }
 
-    return $self->cvs_cmd($cmd);
-}
+    sub status 
+    {
+# status()
+# status(file1, ... )
+        my($self) = shift;
+        my(@args) = @_;
 
-sub upd {
-    goto &update;
-}
+        my($cmd) = $self->_cmd('status -v');
 
-sub update {
+        if(@args) {
+            $cmd .= join ' ' => @args;
+        }
+
+        return $self->cvs_cmd($cmd);
+    }
+
+    sub upd 
+    {
+        goto &update;
+    }
+
+    sub update 
+    {
 # update() -> update workspace (cvs -q update -d).
 # update(file) -> update file  (cvs -q update file [file ... ]).
 # Doesn't permit -r.
-    my($self) = shift;
-    my(@args) = @_;
+        my($self) = shift;
+        my(@args) = @_;
 
-    my($cmd) = $self->_cmd('-q update');
+        my($cmd) = $self->_cmd('-q update');
 
-    $cmd .= @args   ? join ' ' => @args
-                    : '-d';
+        $cmd .= @args   ? join ' ' => @args
+        : '-d';
 
-    return $self->cvs_cmd($cmd);
-}
+        return $self->cvs_cmd($cmd);
+    }
 
-    sub up2date {
+    sub up2date 
+    {
     # Checks workspace status. No args.
         my($self) = shift;
 
@@ -406,7 +422,8 @@ sub update {
         return $self->cvs_cmd($cmd);
     }
 
-    sub DESTROY {
+    sub DESTROY 
+    {
         my($self) = shift;
         delete($cvs_bin_of {ident $self});
         delete($external_of{ident $self});
@@ -414,7 +431,6 @@ sub update {
 
         return;
     }
-
 }
 
 1;
@@ -431,7 +447,7 @@ Cvs::Simple - Perl interface to cvs.
 
 =head1 VERSION
 
-version 0.07_01
+version 0.07_02
 
 =head1 SYNOPSIS
 
